@@ -765,7 +765,7 @@ def start(ctx,
     if use_r():
         version = metaflow_r_version()
 
-    echo('Aero Platform', fg='magenta', bold=True, nl=False)
+    echo('Aero Platform [beta]', fg='magenta', bold=True, nl=True)
     echo('Metaflow %s' % version, bold=True, nl=False)
     echo(" executing *%s*" % ctx.obj.flow.name, fg='magenta', nl=False)
     echo(" for *%s*" % resolve_identity(), fg='magenta')
