@@ -156,36 +156,36 @@ class BatchJob(object):
             job_definition['containerProperties']['networkConfiguration'] = \
                 {'assignPublicIp': 'ENABLED'}
         
-        if platform == 'EC2' or platform == 'SPOT':
-            if 'linuxParameters' not in job_definition['containerProperties']:
-                job_definition['containerProperties']['linuxParameters'] = {}
-            if shared_memory is not None:
-                if not (isinstance(shared_memory, (int, unicode, basestring)) and 
-                    int(shared_memory) > 0):
-                    raise BatchJobException(
-                        'Invalid shared memory size value ({}); '
-                        'it should be greater than 0'.format(shared_memory))
-                else:
-                    job_definition['containerProperties'] \
-                        ['linuxParameters']['sharedMemorySize'] = int(shared_memory)
-            if swappiness is not None: 
-                if not (isinstance(swappiness, (int, unicode, basestring)) and 
-                    int(swappiness) >= 0 and int(swappiness) < 100):
-                    raise BatchJobException(
-                        'Invalid swappiness value ({}); '
-                        '(should be 0 or greater and less than 100)'.format(swappiness))
-                else:
-                    job_definition['containerProperties'] \
-                        ['linuxParameters']['swappiness'] = int(swappiness)
-            if max_swap is not None: 
-                if not (isinstance(max_swap, (int, unicode, basestring)) and 
-                    int(max_swap) >= 0):
-                    raise BatchJobException(
-                        'Invalid swappiness value ({}); '
-                        '(should be 0 or greater)'.format(max_swap))
-                else:
-                    job_definition['containerProperties'] \
-                        ['linuxParameters']['maxSwap'] = int(max_swap)
+        # if platform == 'EC2' or platform == 'SPOT':
+        #     if 'linuxParameters' not in job_definition['containerProperties']:
+        #         job_definition['containerProperties']['linuxParameters'] = {}
+        #     if shared_memory is not None:
+        #         if not (isinstance(shared_memory, (int, unicode, basestring)) and 
+        #             int(shared_memory) > 0):
+        #             raise BatchJobException(
+        #                 'Invalid shared memory size value ({}); '
+        #                 'it should be greater than 0'.format(shared_memory))
+        #         else:
+        #             job_definition['containerProperties'] \
+        #                 ['linuxParameters']['sharedMemorySize'] = int(shared_memory)
+        #     if swappiness is not None: 
+        #         if not (isinstance(swappiness, (int, unicode, basestring)) and 
+        #             int(swappiness) >= 0 and int(swappiness) < 100):
+        #             raise BatchJobException(
+        #                 'Invalid swappiness value ({}); '
+        #                 '(should be 0 or greater and less than 100)'.format(swappiness))
+        #         else:
+        #             job_definition['containerProperties'] \
+        #                 ['linuxParameters']['swappiness'] = int(swappiness)
+        #     if max_swap is not None: 
+        #         if not (isinstance(max_swap, (int, unicode, basestring)) and 
+        #             int(max_swap) >= 0):
+        #             raise BatchJobException(
+        #                 'Invalid swappiness value ({}); '
+        #                 '(should be 0 or greater)'.format(max_swap))
+        #         else:
+        #             job_definition['containerProperties'] \
+        #                 ['linuxParameters']['maxSwap'] = int(max_swap)
 
         # check if job definition already exists
         def_name = 'metaflow_%s' % \
@@ -204,8 +204,7 @@ class BatchJob(object):
                     (platform == 'FARGATE' or platform == 'FARGATE_SPOT'):
                 raise BatchJobException(
                     '%s \nPlease ensure you have installed boto3>=1.16.29 if '
-                    'you intend to launch AWS Batch jobs on AWS Fargate '
-                    'compute platform.' % ex)
+                    'you intend to launch Aero tasks' % ex)
             else:
                 raise ex
         return response['jobDefinitionArn']
